"""This is where the module comment belongs"""

def print_lol(the_list):

	"""This function returns values from a list and can determine if other lists exixt
		inside a list and print there contents too. :-)"""


	for each_item in the_list:
		if isinstance(each_item,list):
			print_lol(each_item,level)
		else:
			for num in range(level):
				print("\t", end='')
			print (each_item)		
		
		






